import { PageHeaderWrapper } from '@ant-design/pro-layout';
import moment from 'moment';
import PageTable from '@/components/PageTable';
import { getAccountLogList } from '@/services/accountLog'

const formatterTime = (val) => {
  return val ? moment(val).format('YYYY-MM-DD HH:mm:ss') : '';
};

export default (props) => {
  const columns = [
    {
      title: '发生时间',
      dataIndex: 'payDate',
      key: 'payDate',
      search: false,
      render: (t) => formatterTime(t),
    },
    {
      title: '下单人',
      dataIndex: 'personName',
      key: 'personName',
    },
    {
      title: '手机号',
      dataIndex: 'phone',
      key: 'phone',
    },
    {
      title: '订单号',
      dataIndex: 'orderNo',
      key: 'orderNo',
    },
    {
      title: '类型',
      dataIndex: 'chargeType',
      key: 'chargeType',
      render: (_, record) => {
        return record.chargeType === 'order_pay'
          ? '订单收入'
          : record.chargeType === 'order_refund'
            ? '用户退款'
            : record.chargeType === 'withdraw'
              ? '提现' : ''
      },
      valueType: 'select',
      valueEnum: {
        'order_pay': { text: '订单收入' },
        'order_refund': { text: '用户退款' },
        'withdraw': { text: '提现' },
      },
    },
    {
      title: '支付方式',
      dataIndex: 'feeType',
      key: 'feeType',
      search: false,
      render: (_, record) => {
        return record.chargeType === 'order_refund' ? '原路返回' :
          record.chargeType === 'withdraw' ? '银行卡转账' : ''
      },
    },
    {
      title: '费用',
      dataIndex: 'money',
      key: 'money',
      render: (_, record) => {
        return record.chargeType === 'order_pay'
          ? '+' + (record.money / 100) : '-' + (record.money / 100)
      },
      search: false
    },
  ];

  return (
    <PageHeaderWrapper>
      <PageTable
        request={getAccountLogList}
        // expfunc={exportPersonList}
        columns={columns}
        rowKey="logId"
        options={false}
        scroll={{ x: 1500 }}
      />
    </PageHeaderWrapper>
  );
};
