import React, { useState, useEffect } from 'react';
import { Card, Form, Button } from 'antd';
import ProCard from '@ant-design/pro-card';
import { getWithdrawalDetail } from '@/services/withdrawal'
import { history } from 'umi';
import TextArea from 'antd/lib/input/TextArea';

const FormItem = Form.Item;
const formItemLayout = { labelCol: { span: 6 }, wrapperCol: { span: 14 } };
const goBack = () => {
  history.goBack();
};
export default (props) => {
  const { location } = props;
  const { id } = location.query;
  const [withdrawal, setWithdrawal] = useState();
  const [remarks, setRemarks] = useState()

  useEffect(() => {
    getWithdrawalDetail(id).then((res) => {
      setWithdrawal(res)
    }).catch((err) => {
      console.log(err.message)
    });
  }, [id])
  return (
    <Card>
      <ProCard tabs={{ type: 'card' }}>
        <ProCard.TabPane key={1} tab="提现审批">
          <Form {...formItemLayout}>
            <FormItem label="申请人">
              {withdrawal?.userName}
            </FormItem>
            <FormItem label="联系电话">
              {withdrawal?.phone}
            </FormItem>
            <FormItem label="合作社">
              {withdrawal?.orgName}
            </FormItem>
            <FormItem label="合作社余额">
              {withdrawal?.amountLeft / 100}
            </FormItem>
            <FormItem label="提现银行">
              {withdrawal?.bankCard.ownerBank}
            </FormItem>
            <FormItem label="提现账户">
              {withdrawal?.bankCard.cardNo}
            </FormItem>
            <FormItem label="申请金额">
              {withdrawal?.money / 100}
            </FormItem>
            <FormItem label="处理结果">
              <TextArea placeholder='请输入处理结果（必填）' rows='3' style={{ width: '350px' }} value={remarks} onInput={(e) => { setRemarks(e.detail.value) }} />
            </FormItem>
            <FormItem label=" " colon={false}>
              <Button type="primary" style={{ marginRight: '16px' }} onClick={() => goBack()}>
                同意
              </Button>
              <Button type="primary" style={{ marginRight: '16px' }} onClick={() => goBack()}>
                拒绝
              </Button>
              <Button type="default" onClick={() => goBack()}>
                返回
              </Button>
            </FormItem>
          </Form>
        </ProCard.TabPane>
      </ProCard>
    </Card>
  );
};
