import { PageHeaderWrapper } from '@ant-design/pro-layout';
import { history } from 'umi';
import moment from 'moment';
import { Button } from 'antd'
import PageTable from '@/components/PageTable';
import { getWithdrawalList } from '@/services/withdrawal'

const formatterTime = (val) => {
  return val ? moment(val).format('YYYY-MM-DD HH:mm:ss') : '';
};
const goAudit = (val) => {
  history.push(`./withdrawal/audit.jsx?id=${val.withdrawalId}`);
}
export default (props) => {
  const columns = [
    {
      title: '申请时间',
      dataIndex: 'createDate',
      key: 'createDate',
      search: false,
      render: (t) => formatterTime(t),
    },
    {
      title: '申请人',
      dataIndex: 'userName',
      key: 'userName',
    },
    {
      title: '费用',
      dataIndex: 'money',
      key: 'money',
      render: (t) => t / 100,
      search: false
    },
    //未审批  同意  不同意
    {
      title: '审批状态',
      dataIndex: 'auditStatus',
      key: 'auditStatus',
      render: (_, record) => {
        return record.auditStatus === 0 ? '未审批' :
          record.auditStatus === 1 ? '未审批' : '拒绝'
      },
      valueType: 'select',
      valueEnum: {
        0: { text: '未审批' },
        1: { text: '同意' },
        '-1': { text: '拒绝' },
      },
    },
    {
      title: '审批时间',
      dataIndex: 'postedDate',
      key: 'postedDate',
      search: false,
      render: (t) => t != '-' ? formatterTime(t) : '-',
    },
    {
      title: '操作',
      valueType: 'option',
      key: 'option',
      ellipsis: true,
      render: (_, record) => [
        <Button style={{ padding: 0 }} type="link" key={1} onClick={() => goAudit(record)}>
          审批
        </Button>,
      ],
    },
  ];

  return (
    <PageHeaderWrapper>
      <PageTable
        request={getWithdrawalList}
        // expfunc={exportPersonList}
        columns={columns}
        rowKey="withdrawalId"
        options={false}
      />
    </PageHeaderWrapper>
  );
};
